searchData={"items":[{"type":"module","title":"SeedMan","doc":"Save and load seed data to/from the database as compressed backup files.","ref":"SeedMan.html"},{"type":"function","title":"SeedMan.dump_schema_to_seed_file/3","doc":"Dump table data for a given `schema_module` to a file in the seeds directory\n(e.g. `priv/repo/seeds`).\n\nThis function is intended to make it easy to save seed data from an external database so that it\ncan be used to seed local tables during development.\n\n> #### Tip {: .tip}\n>\n> Before calling this function, ensure that you have started the server with the application\n> configured to use the correct database you want to save the seed data from.","ref":"SeedMan.html#dump_schema_to_seed_file/3"},{"type":"function","title":"Options - SeedMan.dump_schema_to_seed_file/3","doc":"- `:comment` - Add a comment to the top of the seed file (e.g. \"Hello world!\").\n\n- `:seed_data` - Specify custom data to dump to the seed file. If this value is not specified,\nthen the full contents of the given schema/table will be dumped as seed data.","ref":"SeedMan.html#dump_schema_to_seed_file/3-options"},{"type":"function","title":"Examples - SeedMan.dump_schema_to_seed_file/3","doc":"Dump the contents of a given schema/table to a seed file:\n\n    iex> SeedMan.dump_schema_to_seed_file(YourProject.Repo, YourProject.Persons.Person)\n    :ok\n\nDump the contents of a given schema/table to a seed file with a custom comment embedded in the\nseed file:\n\n    iex> SeedMan.dump_schema_to_seed_file(\n    ...>   YourProject.Repo,\n    ...>   YourProject.Persons.Person,\n    ...>   comment: \"For anyone who reads this, X was done because of Y.\"\n    ...> )\n    :ok\n\nDump the contents of the current table to a seed file using custom `:seed_data`:\n\n    iex> SeedMan.dump_schema_to_seed_file(\n    ...>   YourProject.Repo,\n    ...>   YourProject.Persons.Person,\n    ...>   seed_data: [%{...}, %{...}],\n    ...> )\n    :ok","ref":"SeedMan.html#dump_schema_to_seed_file/3-examples"},{"type":"function","title":"SeedMan.load_schema_from_seed_file/3","doc":"Load table data for a `schema_module` into a repo by its `repo_module` from an existing seed\ndata file (to save seed data, see `dump_schema_to_seed_file/3`).\n\nThis function is intended to make it easy to load seed data that was previously saved to the\nseed files directory path (e.g. `priv/repo/seeds`) to make it easier to work with a local\ndatabase during development.\n\n> #### Tip {: .tip}\n>\n> Before calling this function, ensure that you have started the server with the application\n> configured to use the correct database you want to load the seed data into.","ref":"SeedMan.html#load_schema_from_seed_file/3"},{"type":"function","title":"Examples - SeedMan.load_schema_from_seed_file/3","doc":"iex> SeedMan.load_schema_from_seed_file(YourProject.Repo, YourProject.Persons.Person)\n    :ok","ref":"SeedMan.html#load_schema_from_seed_file/3-examples"},{"type":"function","title":"Options - SeedMan.load_schema_from_seed_file/3","doc":"- `:insert_all_function_atom` - The 2-arity repo function to use (default: `:insert_all`)\n\n- `:insert_all_opts` - The opts to pass to the `:insert_all` function. Useful if custom options\nmust be passed when calling the function, e.g. placeholders. (default: `[]`)","ref":"SeedMan.html#load_schema_from_seed_file/3-options"},{"type":"function","title":"SeedMan.read_seed_file/3","doc":"Read seed data for a given schema module.\n\nThis function is used to read the seed data before loading it into the database. It is also\nuseful for viewing the contents (including any comments) of seed files.","ref":"SeedMan.html#read_seed_file/3"},{"type":"function","title":"Options - SeedMan.read_seed_file/3","doc":"- `:comment_only?` - If `true`, then just return the comment embedded in the seed file.","ref":"SeedMan.html#read_seed_file/3-options"},{"type":"extras","title":"Readme","doc":"# SeedMan\n\nSave and load seed data to/from the database as compressed backup files. Useful for generating database fixtures (e.g. during development and testing).\n\nThis package was created to make local development easier when working with a remote database with legacy data. Instead of working on a remote database, the data can be replicated locally for easier setup/teardown during development and testing.\n\n> #### Tip {: .tip}\n>\n> This package should probably not be used to store large tables in your project, or tables with sensitive data.\n>\n> In such cases, you may want to use a combination of something like [ExMachina](https://github.com/beam-community/ex_machina) and [Faker](https://github.com/elixirs/faker) to generate a fixture of synthetic data that can be used instead of mirroring large or sensitive tables to your project.","ref":"readme.html"},{"type":"extras","title":"Getting started - Readme","doc":"","ref":"readme.html#getting-started"},{"type":"extras","title":"Installation - Readme","doc":"Add this package to your list of dependencies in `mix.exs`, then run `mix deps.get`:\n\n```elixir\ndef deps do\n  [\n    {:seed_man, \"0.1.4\", only: [:dev, :test]}\n  ]\nend\n```\n\n> NOTE: There is nothing to stop you from running this dependency in `:prod`. It is only excluded in this example for the sake of minimizing unnecessary dependencies in production.","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Readme","doc":"For general usage instructions, see [this project's documentation](https://hexdocs.pm/bulk_upsert/BulkUpsert.html).\n\n#### Using seed data to generate a fixture for development and/or testing\n\nTo restore a fixture, you can add something like this to your `priv/repo/seeds.exs` file after you have dumped your initial seed data:\n\n```elixir\nSeedMan.load_schema_from_seed_file(YourProject.Repo, YourProject.Persons.Person)\n```\n\nNow, when you run `mix ecto.reset`, your backed-up seeds will be automatically loaded into your\ndev/test data.\n\n---\n\nThis project made possible by Interline Travel and Tour Inc.\n\nhttps://www.perx.com/\n\nhttps://www.touchdown.co.uk/\n\nhttps://www.touchdownfrance.com/","ref":"readme.html#usage"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"v0.1.4 - 2025-05-19 - Changelog","doc":"","ref":"changelog.html#v0-1-4-2025-05-19"},{"type":"extras","title":"Fixed - Changelog","doc":"- Break the data into chunks so that large tables don't cause Postgres errors","ref":"changelog.html#fixed"},{"type":"extras","title":"v0.1.3 - 2025-05-19 - Changelog","doc":"","ref":"changelog.html#v0-1-3-2025-05-19"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fix incorrect repo directory name","ref":"changelog.html#fixed"},{"type":"extras","title":"v0.1.2 - 2025-05-19 - Changelog","doc":"","ref":"changelog.html#v0-1-2-2025-05-19"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fix some hardcoded values that were causing issues","ref":"changelog.html#fixed"},{"type":"extras","title":"v0.1.1 - 2025-05-03 - Changelog","doc":"","ref":"changelog.html#v0-1-1-2025-05-03"},{"type":"extras","title":"Added - Changelog","doc":"- Add changelog to HexDocs","ref":"changelog.html#added"},{"type":"extras","title":"v0.1.0 - 2025-04-29 - Changelog","doc":"","ref":"changelog.html#v0-1-0-2025-04-29"},{"type":"extras","title":"Added - Changelog","doc":"- Initial release","ref":"changelog.html#added"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}